<?php

namespace Drupal\meaofd\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\meaofd\Services\Fixer;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a confirmation form for fixing an entity.
 */
class MismatchedEntityAndOrFieldDefinitionsReportFixForm extends ConfirmFormBase {

  /**
   * The mismatched entity and/or field definitions fixer service.
   *
   * @var \Drupal\meaofd\Services\Fixer
   */
  protected $fixer;

  /**
   * The entity type to fix.
   *
   * @var string|null
   */
  protected $entityType;

  /**
   * Constructor.
   *
   * @param \Drupal\meaofd\Services\Fixer $fixer
   *   The mismatched entity and/or field definitions fixer service.
   */
  public function __construct(Fixer $fixer) {
    $this->fixer = $fixer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('meaofd.fixer'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'meaofd_fix_confirmation_form';
  }

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {
    return $this->t('Are you sure you want to fix mismatched %entity_type definitions?', ['%entity_type' => $this->entityType]);
  }

  /**
   * {@inheritdoc}
   */
  public function getCancelUrl() {
    return new Url('meaofd.report');
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, $entity_type = NULL) {
    $this->entityType = $entity_type;
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    if (is_string($this->entityType) && strlen($this->entityType) > 0) {
      $entities_fixed = $this->fixer->fix($this->entityType, TRUE, TRUE);

      foreach ($entities_fixed as $entity_fixed) {
        $this->messenger()->addMessage($this->t('Entity %entity_type has been fixed.', ['%entity_type' => $entity_fixed]));
      }
    }
    else {
      $this->messenger()->addError($this->t('Invalid entity type.'));
    }

    $form_state->setRedirectUrl($this->getCancelUrl());
  }

}
